namespace SampleApp.Controllers
{
    using System.Data;
    using System.Data.Entity;
    using System.Linq;
    using System.Web.Mvc;

    using SampleApp.Models;

    public class ProductsController : Controller
    {
        private SampleAppContext context = new SampleAppContext();

        //
        // GET: /Products/

        public ViewResult Index()
        {
            return View(context.Products.Include(product => product.Category).ToList());
        }

        //
        // GET: /Products/Details/5

        public ViewResult Details(int id)
        {
            Product product = context.Products.Single(x => x.Id == id);
            return View(product);
        }

        //
        // GET: /Products/Create

        public ActionResult Create()
        {
            ViewBag.PossibleCategories = context.Categories;
            return View();
        } 

        //
        // POST: /Products/Create

        [HttpPost]
        public ActionResult Create(Product product)
        {
            if (ModelState.IsValid)
            {
                context.Products.Add(product);
                context.SaveChanges();
                return RedirectToAction("Index");  
            }

            ViewBag.PossibleCategories = context.Categories;
            return View(product);
        }
        
        //
        // GET: /Products/Edit/5
 
        public ActionResult Edit(int id)
        {
            Product product = context.Products.Single(x => x.Id == id);
            ViewBag.PossibleCategories = context.Categories;
            return View(product);
        }

        //
        // POST: /Products/Edit/5

        [HttpPost]
        public ActionResult Edit(Product product)
        {
            if (ModelState.IsValid)
            {
                context.Entry(product).State = EntityState.Modified;
                context.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.PossibleCategories = context.Categories;
            return View(product);
        }

        //
        // GET: /Products/Delete/5
 
        public ActionResult Delete(int id)
        {
            Product product = context.Products.Single(x => x.Id == id);
            return View(product);
        }

        //
        // POST: /Products/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            Product product = context.Products.Single(x => x.Id == id);
            context.Products.Remove(product);
            context.SaveChanges();
            return RedirectToAction("Index");
        }
    }
}